// Google Maps firma bilgi toplayıcı

// Global değişkenler
let devamEdiyor = false;
let firmalar = [];
let toplamFirmaSayisi = null;
let bulunanFirmaSayisi = 0;
let taranacakFirmalar = [];
let scrollInterval = null;

// CSS Selektörleri - Google Maps'in güncellenmiş selektörleri
const SELECTORS = {
  // Firma listesi selektörleri - bunu çok basit tutuyoruz
  firmaListesi: '.Nv2PK',
  firmaBaslik: 'h3.fontHeadlineSmall',
  firmaKart: '.hfpxzc',
  
  // Detay paneli selektörleri
  detayPanel: '.m6QErb.DxyBCb.kA9KIf.dS8AEf',
  firmaAdi: 'h1.DUwDvf',
  // Telefon ve website için genişletilmiş selektörler
  telefon: '[data-item-id="phone:tel:"] span.fontBodyMedium, [data-tooltip="Telefon numarası"]',
  website: '[data-item-id^="authority"] span.fontBodyMedium, [data-tooltip="Web sitesi"]'
};

// Chrome mesaj dinleyicisi
chrome.runtime.onMessage.addListener((message, sender, sendResponse) => {
  if (message.action === 'baslatTarama') {
    toplamFirmaSayisi = message.firmaSayisi;
    baslatTarama();
    sendResponse({durum: 'Tarama başlatıldı'});
    return true;
  } else if (message.action === 'durdurTarama') {
    durdurTarama();
    sendResponse({durum: 'Tarama durduruldu'});
    return true;
  }
});

// Taramayı başlat
function baslatTarama() {
  devamEdiyor = true;
  firmalar = [];
  bulunanFirmaSayisi = 0;
  
  // Local storage'a başlangıç durumunu kaydet
  chrome.storage.local.set({
    devamEdiyor: true,
    firmalar: [],
    toplamFirma: toplamFirmaSayisi,
    bulunanFirma: 0
  });
  
  // Sayfadaki firmaları bul
  setTimeout(() => {
    tumFirmalariTara();
  }, 2000);
}

// Taramayı durdur
function durdurTarama() {
  devamEdiyor = false;
  
  if (scrollInterval) {
    clearInterval(scrollInterval);
    scrollInterval = null;
  }
  
  // Local storage'a durma durumunu kaydet
  chrome.storage.local.set({
    devamEdiyor: false
  });
  
  console.log('Tarama durduruldu.');
}

// Tüm firmaları tara
function tumFirmalariTara() {
  console.log('Firma taraması başlatılıyor...');
  
  // Sayfadaki firma kartlarını bul
  taranacakFirmalar = Array.from(document.querySelectorAll(SELECTORS.firmaListesi));
  
  if (taranacakFirmalar.length === 0) {
    console.log('Firma listesi bulunamadı. Sayfa tam olarak yüklenmiş olmayabilir.');
    setTimeout(tumFirmalariTara, 2000);
    return;
  }
  
  console.log(`Toplam ${taranacakFirmalar.length} firma bulundu.`);
  
  // Belirli bir sayıda tarama isteniyorsa
  if (toplamFirmaSayisi && toplamFirmaSayisi > 0) {
    console.log(`Belirtilen ${toplamFirmaSayisi} firma taranacak.`);
    
    // Talep edilen firma sayısı listede bulunanlardan fazlaysa daha fazla firma yüklemek için scroll yap
    if (toplamFirmaSayisi > taranacakFirmalar.length) {
      scrollVeYeniFirmalariBul();
    } else {
      // Talep edilen sayı kadar firma tara
      taranacakFirmalar = taranacakFirmalar.slice(0, toplamFirmaSayisi);
      firmaDetaylariniTara();
    }
  } else {
    // Sayı belirtilmediyse tüm firmaları tara
    console.log('Tüm firmalar taranacak.');
    
    // Daha fazla firma yüklemek için scroll yap
    scrollVeYeniFirmalariBul();
  }
}

// Daha fazla firma yüklemek için scroll yapma
function scrollVeYeniFirmalariBul() {
  let oncekiFirmaSayisi = taranacakFirmalar.length;
  let scrollDenemeSayisi = 0;
  const maxDenemeSayisi = 20; // Maksimum scroll deneme sayısı
  
  console.log('Daha fazla firma yüklemek için scroll yapılıyor...');
  
  // Panel elementini bul
  const panel = document.querySelector('div[role="feed"]');
  if (!panel) {
    console.log('Scroll yapılacak panel bulunamadı');
    firmaDetaylariniTara();
    return;
  }
  
  // Scroll interval başlat
  scrollInterval = setInterval(() => {
    if (!devamEdiyor) {
      clearInterval(scrollInterval);
      return;
    }
    
    // Panelin en altına scroll yap
    panel.scrollTo(0, panel.scrollHeight);
    
    // Yeni firma sayısını kontrol et
    setTimeout(() => {
      const guncelFirmalar = Array.from(document.querySelectorAll(SELECTORS.firmaListesi));
      
      // Yeni firma bulunamadıysa ve maksimum deneme sayısına ulaşıldıysa
      if (guncelFirmalar.length === oncekiFirmaSayisi) {
        scrollDenemeSayisi++;
        
        if (scrollDenemeSayisi >= maxDenemeSayisi) {
          console.log(`Maksimum deneme sayısına ulaşıldı. Daha fazla firma yüklenemedi. Toplam: ${guncelFirmalar.length}`);
          
          clearInterval(scrollInterval);
          scrollInterval = null;
          
          // Belirli bir sayı istendiyse ve hala yetersizse mevcut listeyi kullan
          if (toplamFirmaSayisi && toplamFirmaSayisi > 0) {
            taranacakFirmalar = guncelFirmalar.slice(0, Math.min(toplamFirmaSayisi, guncelFirmalar.length));
          } else {
            taranacakFirmalar = guncelFirmalar;
          }
          
          firmaDetaylariniTara();
        }
      } else {
        // Yeni firmalar bulundu, sayıyı güncelle
        scrollDenemeSayisi = 0;
        oncekiFirmaSayisi = guncelFirmalar.length;
        console.log(`Şu ana kadar yüklenen firma sayısı: ${guncelFirmalar.length}`);
        taranacakFirmalar = guncelFirmalar;
        
        // Talep edilen sayıya ulaşıldıysa
        if (toplamFirmaSayisi && toplamFirmaSayisi > 0 && guncelFirmalar.length >= toplamFirmaSayisi) {
          console.log(`Talep edilen ${toplamFirmaSayisi} firma sayısına ulaşıldı.`);
          
          clearInterval(scrollInterval);
          scrollInterval = null;
          
          taranacakFirmalar = guncelFirmalar.slice(0, toplamFirmaSayisi);
          firmaDetaylariniTara();
        }
      }
    }, 1000);
  }, 2000);
}

// Firma detaylarını tara
async function firmaDetaylariniTara() {
  if (!devamEdiyor) return;
  
  console.log(`${taranacakFirmalar.length} firma detayları taranacak.`);
  
  // Her firma için döngü
  for (let i = 0; i < taranacakFirmalar.length; i++) {
    if (!devamEdiyor) break;
    
    const firmaElementi = taranacakFirmalar[i];
    
    try {
      // Firma kartını bul
      const firmaKart = firmaElementi.querySelector(SELECTORS.firmaKart);
      if (!firmaKart) {
        console.log("Firma kartı bulunamadı, geçiliyor...");
        continue;
      }
      
      // Firma adını başlıktan al
      const baslikElement = firmaElementi.querySelector(SELECTORS.firmaBaslik);
      let firmaAdi = baslikElement ? baslikElement.textContent.trim() : '';
      
      if (!firmaAdi) {
        // Alternatif yöntem: Aria-label kullan
        firmaAdi = firmaKart.getAttribute('aria-label') || 'Firma';
      }
      
      console.log(`(${i+1}/${taranacakFirmalar.length}) Firma detayları alınıyor: ${firmaAdi}`);
      
      // Firma kartına tıkla
      firmaKart.click();
      
      // Detayların yüklenmesini bekle
      await bekle(2000);
      
      // Detay panelinden bilgileri çek
      const telefon = getTelefon();
      const website = getWebsite();
      
      console.log(`Telefon: ${telefon}, Website: ${website}`);
      
      // Firma bilgilerini kaydet
      const firmaBilgisi = {
        ad: firmaAdi,
        telefon: telefon,
        website: website
      };
      
      firmalar.push(firmaBilgisi);
      bulunanFirmaSayisi++;
      
      // İlerleme durumunu storage'a kaydet
      chrome.storage.local.set({
        firmalar: firmalar,
        bulunanFirma: bulunanFirmaSayisi
      });
      
      console.log(`Firma bilgileri alındı: ${JSON.stringify(firmaBilgisi)}`);
      
      // Bir sonraki firmaya geçmeden önce kısa bir bekleme
      await bekle(500);
    } catch (err) {
      console.error(`Hata oluştu: ${err.message}`);
    }
  }
  
  // Tarama tamamlandı
  console.log(`Tarama tamamlandı. Toplam ${firmalar.length} firma bilgisi alındı.`);
  devamEdiyor = false;
  
  // Tarama tamamlandı durumunu storage'a kaydet
  chrome.storage.local.set({
    devamEdiyor: false,
    firmalar: firmalar
  });
}

// Telefon numarasını al
function getTelefon() {
  try {
    // Ana selektör ile dene
    const telefonElement = document.querySelector(SELECTORS.telefon);
    if (telefonElement && telefonElement.textContent) {
      return telefonElement.textContent.trim();
    }
    
    // Buton öğesi üzerinden dene
    const telefonButton = document.querySelector('button[data-item-id^="phone:tel:"]');
    if (telefonButton) {
      // Aria-label özelliğini kontrol et
      const ariaLabel = telefonButton.getAttribute('aria-label');
      if (ariaLabel) {
        // "Ara: +90 555 123 4567" formatından telefon numarasını çıkar
        return ariaLabel.replace('Ara: ', '').trim();
      }
    }
    
    // Farklı bir alternatif selektör dene
    const telefonLinkElement = document.querySelector('a[href^="tel:"]');
    if (telefonLinkElement) {
      return telefonLinkElement.getAttribute('href').replace('tel:', '');
    }
    
    return 'Bulunamadı';
  } catch (err) {
    console.error('Telefon alınamadı:', err);
    return 'Bulunamadı';
  }
}

// Web sitesini al
function getWebsite() {
  try {
    // Ana selektör ile dene
    const websiteElement = document.querySelector(SELECTORS.website);
    if (websiteElement && websiteElement.textContent) {
      return websiteElement.textContent.trim();
    }
    
    // Link öğesi üzerinden dene
    const websiteLink = document.querySelector('a[data-item-id^="authority"]');
    if (websiteLink) {
      // Link metni varsa onu döndür
      if (websiteLink.textContent) {
        return websiteLink.textContent.trim();
      }
      
      // veya href özelliğini kontrol et
      const href = websiteLink.getAttribute('href');
      if (href) {
        // Google yönlendirme URL'sini düzelt
        if (href.includes('url=')) {
          const match = href.match(/url=([^&]+)/);
          if (match && match[1]) {
            return decodeURIComponent(match[1]);
          }
        }
        
        // Doğrudan URL
        return href;
      }
    }
    
    // Alternatif selektör dene
    const altWebsiteElement = document.querySelector('a[aria-label*="website"], a[aria-label*="web sitesi"]');
    if (altWebsiteElement) {
      return altWebsiteElement.textContent || altWebsiteElement.getAttribute('href') || 'Bulunamadı';
    }
    
    return 'Bulunamadı';
  } catch (err) {
    console.error('Website alınamadı:', err);
    return 'Bulunamadı';
  }
}

// Bekleme yardımcı fonksiyonu
function bekle(ms) {
  return new Promise(resolve => setTimeout(resolve, ms));
} 