document.addEventListener('DOMContentLoaded', () => {
  const baslatBtn = document.getElementById('baslatBtn');
  const durdurBtn = document.getElementById('durdurBtn');
  const csvIndir = document.getElementById('csvIndir');
  const durumDiv = document.getElementById('durum');
  const ilerlemeDiv = document.getElementById('ilerleme');
  const firmaSayisiInput = document.getElementById('firmaSayisi');
  
  // Modal elemanları
  const kullanımModal = document.getElementById('kullanımModal');
  const yardimBtn = document.getElementById('yardimBtn');
  const kapatModal = document.getElementById('kapatModal');
  const kapatBtn = document.getElementById('kapat');

  let taramaDevamEdiyor = false;

  // Chrome storage'dan veri alma
  function getDurum() {
    chrome.storage.local.get(['firmalar', 'devamEdiyor', 'toplamFirma', 'bulunanFirma'], (result) => {
      taramaDevamEdiyor = result.devamEdiyor || false;
      
      if (taramaDevamEdiyor) {
        baslatBtn.disabled = true;
        durdurBtn.disabled = false;
        durumDiv.textContent = 'Tarama devam ediyor...';
        durumDiv.className = 'status success';
        durumDiv.style.display = 'block';
      } else {
        baslatBtn.disabled = false;
        durdurBtn.disabled = true;
        
        if (result.firmalar && result.firmalar.length > 0) {
          durumDiv.textContent = `Tarama tamamlandı. ${result.firmalar.length} firma bulundu.`;
          durumDiv.className = 'status success';
          durumDiv.style.display = 'block';
          csvIndir.disabled = false;
          
          // Bulunan firmaları göster
          result.firmalar.forEach((firma, index) => {
            console.log(`Firma ${index+1}:`, firma);
          });
        } else {
          csvIndir.disabled = true;
        }
      }
      
      // İlerleme bilgisini güncelle
      if (result.toplamFirma && result.bulunanFirma) {
        ilerlemeDiv.textContent = `İşlem: ${result.bulunanFirma} / ${result.toplamFirma}`;
      }
    });
  }

  // Sayfa yüklendiğinde durumu kontrol et
  getDurum();
  
  // Durum bilgisini periyodik olarak güncelle
  setInterval(getDurum, 1000);

  // Taramayı başlat
  baslatBtn.addEventListener('click', () => {
    const firmaSayisi = firmaSayisiInput.value ? parseInt(firmaSayisiInput.value) : null;
    
    chrome.tabs.query({active: true, currentWindow: true}, (tabs) => {
      const tab = tabs[0];
      if (tab.url.includes('google.com/maps')) {
        chrome.storage.local.set({
          devamEdiyor: true,
          firmalar: [],
          toplamFirma: firmaSayisi,
          bulunanFirma: 0
        }, () => {
          chrome.tabs.sendMessage(tab.id, {
            action: 'baslatTarama',
            firmaSayisi: firmaSayisi
          });
          
          baslatBtn.disabled = true;
          durdurBtn.disabled = false;
          durumDiv.textContent = 'Tarama başlatıldı...';
          durumDiv.className = 'status success';
          durumDiv.style.display = 'block';
        });
      } else {
        durumDiv.textContent = 'Bu işlem sadece Google Maps sayfasında çalışır.';
        durumDiv.className = 'status error';
        durumDiv.style.display = 'block';
      }
    });
  });

  // Taramayı durdur
  durdurBtn.addEventListener('click', () => {
    chrome.tabs.query({active: true, currentWindow: true}, (tabs) => {
      chrome.tabs.sendMessage(tabs[0].id, {action: 'durdurTarama'});
      chrome.storage.local.set({devamEdiyor: false}, () => {
        baslatBtn.disabled = false;
        durdurBtn.disabled = true;
        durumDiv.textContent = 'Tarama durduruldu.';
        durumDiv.className = 'status error';
        durumDiv.style.display = 'block';
      });
    });
  });

  // CSV dosyasını indir
  csvIndir.addEventListener('click', () => {
    chrome.storage.local.get(['firmalar'], (result) => {
      if (result.firmalar && result.firmalar.length > 0) {
        const firmalar = result.firmalar;
        
        // CSV başlık satırı
        let csvIcerik = 'Firma Adı,Telefon,Website\n';
        
        // Firma verilerini CSV formatına dönüştür
        firmalar.forEach(firma => {
          const firmaAdi = firma.ad ? `"${firma.ad.replace(/"/g, '""')}"` : '"Bulunamadı"';
          const telefon = firma.telefon ? `"${firma.telefon.replace(/"/g, '""')}"` : '"Bulunamadı"';
          const website = firma.website ? `"${firma.website.replace(/"/g, '""')}"` : '"Bulunamadı"';
          
          csvIcerik += `${firmaAdi},${telefon},${website}\n`;
        });
        
        // CSV dosyasını oluştur ve indir
        const blob = new Blob([csvIcerik], {type: 'text/csv;charset=utf-8;'});
        const url = URL.createObjectURL(blob);
        const tarih = new Date().toISOString().slice(0, 10);
        const dosyaAdi = `google_maps_firmalar_${tarih}.csv`;
        
        chrome.downloads.download({
          url: url,
          filename: dosyaAdi,
          saveAs: true
        });
        
        durumDiv.textContent = 'CSV dosyası indiriliyor...';
        durumDiv.className = 'status success';
        durumDiv.style.display = 'block';
      } else {
        durumDiv.textContent = 'İndirilecek veri bulunamadı.';
        durumDiv.className = 'status error';
        durumDiv.style.display = 'block';
      }
    });
  });
  
  // Modal işlevleri
  // Yardım butonuna tıklandığında modali göster
  yardimBtn.addEventListener('click', () => {
    kullanımModal.style.display = 'block';
  });
  
  // Modal kapatma işlevleri
  kapatModal.addEventListener('click', () => {
    kullanımModal.style.display = 'none';
  });
  
  kapatBtn.addEventListener('click', () => {
    kullanımModal.style.display = 'none';
  });
  
  // Modal dışına tıklandığında kapat
  window.addEventListener('click', (event) => {
    if (event.target === kullanımModal) {
      kullanımModal.style.display = 'none';
    }
  });
}); 