// Node.js ile çalıştırılacak ikon oluşturma scripti
// Gerekli modüller: canvas, fs
// npm install canvas fs

const { createCanvas } = require('canvas');
const fs = require('fs');

// İkon oluşturma fonksiyonu
function createIcon(size, backgroundColor, textColor) {
  const canvas = createCanvas(size, size);
  const ctx = canvas.getContext('2d');
  
  // Arka plan
  ctx.fillStyle = backgroundColor;
  ctx.fillRect(0, 0, size, size);
  
  // Kenar çizgisi
  ctx.strokeStyle = '#ffffff';
  ctx.lineWidth = Math.max(1, size / 16);
  ctx.strokeRect(Math.floor(size/10), Math.floor(size/10), 
                size - 2*Math.floor(size/10), size - 2*Math.floor(size/10));
  
  // "G" harfi
  ctx.fillStyle = textColor;
  ctx.font = `bold ${Math.floor(size * 0.5)}px Arial`;
  ctx.textAlign = 'center';
  ctx.textBaseline = 'middle';
  ctx.fillText('G', size / 2, size / 2 - size/10);
  
  // Veri simgesi (alt kısımda çizgi)
  const lineWidth = Math.floor(size * 0.5);
  const lineHeight = Math.max(1, Math.floor(size * 0.06));
  const lineTop = Math.floor(size * 0.65);
  
  ctx.fillStyle = textColor;
  ctx.fillRect((size - lineWidth) / 2, lineTop, lineWidth, lineHeight);
  
  // İkinci çizgi
  ctx.fillRect((size - lineWidth) / 2, lineTop + 2*lineHeight, lineWidth, lineHeight);
  
  return canvas.toBuffer('image/png');
}

// İkonları oluştur ve dosyaya kaydet
const sizes = [16, 48, 128];

sizes.forEach(size => {
  const buffer = createIcon(size, '#4285f4', '#ffffff');
  fs.writeFileSync(`images/icon${size}.png`, buffer);
  console.log(`icon${size}.png oluşturuldu.`);
});

console.log('Tüm ikonlar oluşturuldu.'); 